@@ -25,14 +25,17 @@ class MongodbPool(BaseConnectionPool):
             host_str = info.host.split(",")
             hosts = ",".join([f"{host}:{info.port}" for host in host_str])
             conn_info_string = f"mongodb://{info.user}:{info.password}@{hosts}"
-            if info.params:
-                if info.params == "LDAP":
-                    conn_info_string += "/?authMechanism=PLAIN"
-                elif info.params == "Password":
-                    conn_info_string += "/?authSource=admin"
-                elif info.params == "X509":
-                    conn_info_string += "/?authMechanism=MONGODB-X509"
-            pool = motor.motor_tornado.MotorClient(conn_info_string)
+            params = info.params
+            if not isinstance(params, dict):
+                if params and isinstance(params, str):
+                    if params == "LDAP":
+                        conn_info_string += "/?authMechanism=PLAIN"
+                    elif params == "Password":
+                        conn_info_string += "/?authSource=admin"
+                    elif params == "X509":
+                        conn_info_string += "/?authMechanism=MONGODB-X509"
+                params = dict()
+            pool = motor.motor_tornado.MotorClient(conn_info_string, **params)
             return pool
         else:
             raise NotImplementedError
@@ -46,12 +49,15 @@ class MongodbPool(BaseConnectionPool):
         host_str = info.host.split(",")
         hosts = ",".join([f"{host}:{info.port}" for host in host_str])
         conn_info_string = f"mongodb://{info.user}:{info.password}@{hosts}"
-        if info.params:
-            if info.params == "LDAP":
-                conn_info_string += "/?authMechanism=PLAIN"
-            elif info.params == "Password":
-                conn_info_string += "/?authSource=admin"
-            elif info.params == "X509":
-                conn_info_string += "/?authMechanism=MONGODB-X509"
-        pool = pymongo.MongoClient(conn_info_string)
+        params = info.params
+        if not isinstance(params, dict):
+            if params and isinstance(params, str):
+                if info.params == "LDAP":
+                    conn_info_string += "/?authMechanism=PLAIN"
+                elif info.params == "Password":
+                    conn_info_string += "/?authSource=admin"
+                elif info.params == "X509":
+                    conn_info_string += "/?authMechanism=MONGODB-X509"
+            params = dict()
+        pool = pymongo.MongoClient(conn_info_string, **params)
         return pool
